@@ -13,7 +13,7 @@ from swh.loader.git.from_disk import GitLoaderFromDisk, GitLoaderFromArchive
 from swh.loader.git.loader import GitLoader
 
 
-@shared_task(name=__name__ + '.UpdateGitRepository')
+@shared_task(name=__name__ + ".UpdateGitRepository")
 def load_git(*, url: str, base_url: Optional[str] = None) -> Dict[str, Any]:
     """Import a git repository from a remote location
 
@@ -22,9 +22,8 @@ def load_git(*, url: str, base_url: Optional[str] = None) -> Dict[str, Any]:
     return loader.load()
 
 
-@shared_task(name=__name__ + '.LoadDiskGitRepository')
-def load_git_from_dir(
-        *, url: str, directory: str, date: str) -> Dict[str, Any]:
+@shared_task(name=__name__ + ".LoadDiskGitRepository")
+def load_git_from_dir(*, url: str, directory: str, date: str) -> Dict[str, Any]:
     """Import a git repository from a local repository
 
        Import a git repository, cloned in `directory` from `origin_url` at
@@ -32,14 +31,12 @@ def load_git_from_dir(
 
     """
     visit_date = dateutil.parser.parse(date)
-    loader = GitLoaderFromDisk(
-        url, directory=directory, visit_date=visit_date)
+    loader = GitLoaderFromDisk(url, directory=directory, visit_date=visit_date)
     return loader.load()
 
 
-@shared_task(name=__name__ + '.UncompressAndLoadDiskGitRepository')
-def load_git_from_zip(
-        *, url: str, archive_path: str, date: str) -> Dict[str, Any]:
+@shared_task(name=__name__ + ".UncompressAndLoadDiskGitRepository")
+def load_git_from_zip(*, url: str, archive_path: str, date: str) -> Dict[str, Any]:
     """Import a git repository from a zip archive
 
     1. Uncompress an archive repository in a local and temporary folder
@@ -48,6 +45,5 @@ def load_git_from_zip(
 
     """
     visit_date = dateutil.parser.parse(date)
-    loader = GitLoaderFromArchive(
-        url, archive_path=archive_path, visit_date=visit_date)
+    loader = GitLoaderFromArchive(url, archive_path=archive_path, visit_date=visit_date)
     return loader.load()
